@@ -60,7 +60,10 @@ class K3SController:
         response=requests.post(f'{self.url}/node', headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
-        return NodeInfoDO(**info)
+        if info is None:
+            return None
+        else:
+            return NodeInfoDO(**info)
 
     @exception_class_dec(max_try=1)
     def delete_nodes(self, node_infos: List[Union[NodeInfoDO, NodeMetaDO]], timeout=60):
